@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -62,6 +62,7 @@
 #include <connectivity/sqlparse.hxx>
 #include <tools/debug.hxx>
 #include <tools/diagnose_ex.h>
+#include <osl/diagnose.h>
 
 #include <algorithm>
 
@@ -89,7 +90,8 @@ ORowSetCache::ORowSetCache(const Reference< XResultSet >& _xRs,
                            sal_Bool&	_bModified,
                            sal_Bool&	_bNew,
                            const ORowSetValueVector& _aParameterValueForCache,
-                           const ::rtl::OUString& i_sRowSetFilter)
+                           const ::rtl::OUString& i_sRowSetFilter,
+                           sal_Int32 i_nMaxRows)
     :m_xSet(_xRs)
     ,m_xMetaData(Reference< XResultSetMetaDataSupplier >(_xRs,UNO_QUERY)->getMetaData())
     ,m_aContext( _rContext )
@@ -126,7 +128,7 @@ ORowSetCache::ORowSetCache(const Reference< XResultSet >& _xRs,
             xUp->cancelRowUpdates();
             _xRs->beforeFirst();
             m_nPrivileges = Privilege::SELECT|Privilege::DELETE|Privilege::INSERT|Privilege::UPDATE;
-            m_pCacheSet = new WrappedResultSet();
+            m_pCacheSet = new WrappedResultSet(i_nMaxRows);
             m_xCacheSet = m_pCacheSet;
             m_pCacheSet->construct(_xRs,i_sRowSetFilter);
             return;
@@ -170,10 +172,10 @@ ORowSetCache::ORowSetCache(const Reference< XResultSet >& _xRs,
             OSL_ENSURE(xTabSup.is(),"ORowSet::execute composer isn't a tablesupplier!");
             Reference<XNameAccess> xTables = xTabSup->getTables();
             Sequence< ::rtl::OUString> aTableNames = xTables->getElementNames();
-            if ( aTableNames.getLength() > 1 && !_rUpdateTableName.getLength() && bNeedKeySet ) 
+            if ( aTableNames.getLength() > 1 && !_rUpdateTableName.getLength() && bNeedKeySet )
             {// here we have a join or union and nobody told us which table to update, so we update them all
                 m_nPrivileges = Privilege::SELECT|Privilege::DELETE|Privilege::INSERT|Privilege::UPDATE;
-                OptimisticSet* pCursor = new OptimisticSet(m_aContext,xConnection,_xAnalyzer,_aParameterValueForCache);
+                OptimisticSet* pCursor = new OptimisticSet(m_aContext,xConnection,_xAnalyzer,_aParameterValueForCache,i_nMaxRows);
                 m_pCacheSet = pCursor;
                 m_xCacheSet = m_pCacheSet;
                 try
@@ -186,7 +188,6 @@ ORowSetCache::ORowSetCache(const Reference< XResultSet >& _xRs,
                 }
                 catch(const Exception&)
                 {
-                    // DBG_UNHANDLED_EXCEPTION();
                 }
                 m_pCacheSet = NULL;
                 m_xCacheSet.clear();
@@ -235,7 +236,7 @@ ORowSetCache::ORowSetCache(const Reference< XResultSet >& _xRs,
     {
         try
         {
-            m_pCacheSet = new OBookmarkSet();
+            m_pCacheSet = new OBookmarkSet(i_nMaxRows);
             m_xCacheSet = m_pCacheSet;
             m_pCacheSet->construct(_xRs,i_sRowSetFilter);
 
@@ -264,12 +265,9 @@ ORowSetCache::ORowSetCache(const Reference< XResultSet >& _xRs,
         // need to check if we could handle this select clause
         bAllKeysFound = bAllKeysFound && (nTablesCount == 1 || checkJoin(xConnection,_xAnalyzer,aUpdateTableName));
 
-        // || !(comphelper::hasProperty(PROPERTY_CANUPDATEINSERTEDROWS,xProp) && any2bool(xProp->getPropertyValue(PROPERTY_CANUPDATEINSERTEDROWS)))
-
-        // oj removed because keyset uses only the next// || (xProp->getPropertySetInfo()->hasPropertyByName(PROPERTY_RESULTSETTYPE) && comphelper::getINT32(xProp->getPropertyValue(PROPERTY_RESULTSETTYPE)) == ResultSetType::FORWARD_ONLY)
         if(!bAllKeysFound )
         {
-            m_pCacheSet = new OStaticSet();
+            m_pCacheSet = new OStaticSet(i_nMaxRows);
             m_xCacheSet = m_pCacheSet;
             m_pCacheSet->construct(_xRs,i_sRowSetFilter);
             m_nPrivileges = Privilege::SELECT;
@@ -306,7 +304,7 @@ ORowSetCache::ORowSetCache(const Reference< XResultSet >& _xRs,
                 }
             }
 
-            OKeySet* pKeySet = new OKeySet(m_aUpdateTable,xUpdateTableKeys,aUpdateTableName ,_xAnalyzer,_aParameterValueForCache);
+            OKeySet* pKeySet = new OKeySet(m_aUpdateTable,xUpdateTableKeys,aUpdateTableName ,_xAnalyzer,_aParameterValueForCache,i_nMaxRows);
             try
             {
                 m_pCacheSet = pKeySet;
@@ -333,7 +331,7 @@ ORowSetCache::ORowSetCache(const Reference< XResultSet >& _xRs,
                 if ( m_pCacheSet )
                     m_pCacheSet = NULL;
                 m_xCacheSet = NULL;
-                m_pCacheSet = new OStaticSet();
+                m_pCacheSet = new OStaticSet(i_nMaxRows);
                 m_xCacheSet = m_pCacheSet;
                 m_pCacheSet->construct(_xRs,i_sRowSetFilter);
                 m_nPrivileges = Privilege::SELECT;
@@ -369,9 +367,8 @@ ORowSetCache::~ORowSetCache()
     DBG_DTOR(ORowSetCache,NULL);
 }
 
-void ORowSetCache::setMaxRowSize(sal_Int32 _nSize)
+void ORowSetCache::setFetchSize(sal_Int32 _nSize)
 {
-
     if(_nSize == m_nFetchSize)
         return;
 
@@ -413,7 +410,7 @@ void ORowSetCache::setMaxRowSize(sal_Int32 _nSize)
             m_aMatrixIter = m_pMatrix->end();
         m_aMatrixEnd = m_pMatrix->end();
 
-        // now adjust their positions because a resize invalid all iterators
+        // now adjust their positions because a resize invalidates all iterators
         ::std::vector<sal_Int32>::const_iterator aIter = aPositions.begin();
         ::std::map<sal_Int32,sal_Bool>::const_iterator aPosChangeIter = aCacheIterToChange.begin();
         for(	aCacheIter = m_aCacheIterators.begin();
@@ -463,7 +460,6 @@ Any lcl_getBookmark(ORowSetValue& i_aValue,OCacheSet* i_pCacheSet)
 // ::com::sun::star::sdbcx::XRowLocate
 Any ORowSetCache::getBookmark(  )
 {
-
     if(m_bAfterLast)
         throwFunctionSequenceException(m_xSet.get());
 
@@ -512,7 +508,6 @@ sal_Bool ORowSetCache::moveRelativeToBookmark( const Any& bookmark, sal_Int32 ro
     {
         m_nPosition = m_pCacheSet->getRow() + rows;
         absolute(m_nPosition);
-        //	for(sal_Int32 i=0;i<rows && m_aMatrixIter != m_pMatrix->end();++i,++m_aMatrixIter) ;
 
         bRet = m_aMatrixIter != m_pMatrix->end() && (*m_aMatrixIter).is();
     }
@@ -592,7 +587,7 @@ void ORowSetCache::updateCharacterStream( sal_Int32 columnIndex, const Reference
 
 void ORowSetCache::updateObject( sal_Int32 columnIndex, const Any& x
                                 ,ORowSetValueVector::Vector& io_aRow
-                                ,::std::vector<sal_Int32>& o_ChangedColumns 
+                                ,::std::vector<sal_Int32>& o_ChangedColumns
                                 )
 {
     checkUpdateConditions(columnIndex);
@@ -656,27 +651,21 @@ sal_Bool ORowSetCache::isBeforeFirst(  )
 
 sal_Bool ORowSetCache::isAfterLast(  )
 {
-
     return m_bAfterLast;
 }
 
 sal_Bool ORowSetCache::isFirst(  )
 {
-
     return m_nPosition == 1; // ask resultset for
 }
 
 sal_Bool ORowSetCache::isLast(  )
 {
-    //	return m_bRowCountFinal ? (m_nPosition==m_nRowCount) : m_pCacheSet->isLast();
-
     return m_nPosition == m_nRowCount;
 }
 
 sal_Bool ORowSetCache::beforeFirst(  )
 {
-
-
     if(!m_bBeforeFirst)
     {
         m_bAfterLast	= sal_False;
@@ -691,8 +680,6 @@ sal_Bool ORowSetCache::beforeFirst(  )
 
 sal_Bool ORowSetCache::afterLast(  )
 {
-
-
     if(!m_bAfterLast)
     {
         m_bBeforeFirst = sal_False;
@@ -764,7 +751,6 @@ sal_Bool ORowSetCache::fillMatrix(sal_Int32& _nNewStartPos,sal_Int32 _nNewEndPos
         }
         bCheck = m_pCacheSet->next();
     }
-    //	m_nStartPos = _nNewStartPos;
     // we have to read one row forward to enshure that we know when we are on last row
     // but only when we don't know it already
     if(!m_bRowCountFinal)
@@ -784,12 +770,10 @@ sal_Bool ORowSetCache::fillMatrix(sal_Int32& _nNewStartPos,sal_Int32 _nNewEndPos
 
 sal_Bool ORowSetCache::moveWindow()
 {
-
     sal_Bool bRet = sal_True;
 
     sal_Int32 nDiff = (sal_Int32)(m_nFetchSize*0.5 -0.5);
     sal_Int32 nNewStartPos	= (m_nPosition - nDiff);
-    //	sal_Int32 nNewEndPos	= (m_nPosition+m_nFetchSize*0.5);
     sal_Int32 nNewEndPos	= nNewStartPos + m_nFetchSize;
 
     if ( m_nPosition <= m_nStartPos )
@@ -808,7 +792,6 @@ sal_Bool ORowSetCache::moveWindow()
             if ( nNewStartPos < 1 )
             {
                 bCheck = m_pCacheSet->first();
-                //	aEnd = m_pMatrix->begin() + (sal_Int32)(m_nFetchSize*0.5);
                 OSL_ENSURE((nNewEndPos - m_nStartPos - nNewStartPos) < (sal_Int32)m_pMatrix->size(),"Position is behind end()!");
                 aEnd = m_pMatrix->begin() + (nNewEndPos - m_nStartPos - nNewStartPos);
                 aIter = aEnd;
@@ -864,8 +847,8 @@ sal_Bool ORowSetCache::moveWindow()
                 }
             }
             else
-            { // normaly this should never happen
-                OSL_ENSURE(0,"What the hell is happen here!");
+            { // normally this should never happen
+                OSL_FAIL("What the hell is happen here!");
                 return sal_False;
             }
         }
@@ -944,9 +927,6 @@ sal_Bool ORowSetCache::moveWindow()
             sal_Bool bCheck = m_pCacheSet->absolute(nPos);
             bCheck = fill(aIter,aEnd,nPos,bCheck); // refill the region wew don't need anymore
 
-//			// we know that this is the current maximal rowcount here
-//			if ( !m_bRowCountFinal && bCheck )
-//				m_nRowCount = std::max(nPos,m_nRowCount);
             // we have to read one row forward to enshure that we know when we are on last row
             // but only when we don't know it already
             sal_Bool bOk = sal_True;
@@ -973,7 +953,6 @@ sal_Bool ORowSetCache::moveWindow()
             {	// the end was reached before end() so we can set the start before nNewStartPos
 
                 m_nStartPos += (aIter - m_pMatrix->begin());
-                //	m_nStartPos = (aIter - m_pMatrix->begin());
                 ::std::rotate(m_pMatrix->begin(),aIter,m_pMatrix->end());
                 // now correct the iterator in our iterator vector
                 rotateCacheIterator( (sal_Int16)( aIter - m_pMatrix->begin() ) );
@@ -1250,7 +1229,7 @@ sal_Bool ORowSetCache::insertRow(::std::vector< Any >& o_aBookmarks)
         }
         else
         {
-            OSL_ENSURE(0,"There must be a bookmark after the row was inserted!");
+            OSL_FAIL("There must be a bookmark after the row was inserted!");
         }
     }
     return bRet;
@@ -1273,7 +1252,7 @@ void ORowSetCache::cancelRowModification()
     {
         if ( aCacheIter->second.pRowSet->isInsertRow() && aCacheIter->second.aIterator == m_aInsertRow )
             aCacheIter->second.aIterator = m_pMatrix->end();
-    } // for(;aCacheIter != aCacheEnd;++aCacheIter)
+    }
     resetInsertRow(sal_False);
 }
 
@@ -1290,7 +1269,7 @@ void ORowSetCache::updateRow( ORowSetMatrix::iterator& _rUpdateRow,::std::vector
     m_pCacheSet->updateRow(*_rUpdateRow,*m_aMatrixIter,m_aUpdateTable);
     // refetch the whole row
     (*m_aMatrixIter) = NULL;
-    
+
     if ( moveToBookmark(aBookmark) )
     {
         // update the cached values
@@ -1313,7 +1292,6 @@ bool ORowSetCache::deleteRow(  )
     if(isAfterLast() || isBeforeFirst())
         throw SQLException(DBACORE_RESSTRING(RID_STR_NO_DELETEROW),NULL,SQLSTATE_GENERAL,1000,Any() );
 
-    //	m_pCacheSet->absolute(m_nPosition);
     m_pCacheSet->deleteRow(*m_aMatrixIter,m_aUpdateTable);
     if ( !m_pCacheSet->rowDeleted() )
         return false;
@@ -1340,7 +1318,7 @@ void ORowSetCache::cancelRowUpdates(  )
     m_bNew = m_bModified = sal_False;
     if(!m_nPosition)
     {
-        OSL_ENSURE(0,"cancelRowUpdates:Invalid positions pos == 0");
+        OSL_FAIL("cancelRowUpdates:Invalid positions pos == 0");
         ::dbtools::throwFunctionSequenceException(NULL);
     }
 
@@ -1348,7 +1326,7 @@ void ORowSetCache::cancelRowUpdates(  )
         m_pCacheSet->fillValueRow(*m_aMatrixIter,m_nPosition);
     else
     {
-        OSL_ENSURE(0,"cancelRowUpdates couldn't position right with absolute");
+        OSL_FAIL("cancelRowUpdates couldn't position right with absolute");
         ::dbtools::throwFunctionSequenceException(NULL);
     }
 }
@@ -1376,7 +1354,6 @@ void ORowSetCache::moveToInsertRow(  )
 
 ORowSetCacheIterator ORowSetCache::createIterator(ORowSetBase* _pRowSet)
 {
-
     ORowSetCacheIterator_Helper aHelper;
     aHelper.aIterator = m_pMatrix->end();
     aHelper.pRowSet = _pRowSet;
@@ -1392,7 +1369,7 @@ void ORowSetCache::deleteIterator(const ORowSetBase* _pRowSet)
         {
             m_aCacheIterators.erase(aCacheIter);
             aCacheIter = m_aCacheIterators.begin();
-        } // if ( aCacheIter->second.pRowSet == _pRowSet )
+        }
         else
             ++aCacheIter;
     }
@@ -1466,10 +1443,10 @@ sal_Bool ORowSetCache::checkInnerJoin(const ::connectivity::OSQLParseNode *pNode
     {
         bOk = checkInnerJoin(pNode->getChild(1),_xConnection,_sUpdateTableName);
     }
-    else if ((SQL_ISRULE(pNode,search_condition) || SQL_ISRULE(pNode,boolean_term))	&&			// AND/OR-Verknuepfung:
+    else if ((SQL_ISRULE(pNode,search_condition) || SQL_ISRULE(pNode,boolean_term)) && // AND/OR link
                 pNode->count() == 3)
     {
-        // nur AND Verknpfung zulassen
+        // only allow an AND link
         if ( SQL_ISTOKEN(pNode->getChild(1),AND) )
             bOk = checkInnerJoin(pNode->getChild(0),_xConnection,_sUpdateTableName)
                 && checkInnerJoin(pNode->getChild(2),_xConnection,_sUpdateTableName);
@@ -1477,7 +1454,7 @@ sal_Bool ORowSetCache::checkInnerJoin(const ::connectivity::OSQLParseNode *pNode
     else if (SQL_ISRULE(pNode,comparison_predicate))
     {
         // only the comparison of columns is allowed
-        DBG_ASSERT(pNode->count() == 3,"checkInnerJoin: Fehler im Parse Tree");
+        OSL_ENSURE(pNode->count() == 3,"checkInnerJoin: Fehler im Parse Tree");
         if (!(SQL_ISRULE(pNode->getChild(0),column_ref) &&
                 SQL_ISRULE(pNode->getChild(2),column_ref) &&
                 pNode->getChild(1)->getNodeType() == SQL_NODE_EQUAL))
@@ -1568,7 +1545,7 @@ void ORowSetCache::clearInsertRow()
             aIter->setBound(sal_False);
             aIter->setModified(sal_False);
             aIter->setNull();
-        } // for(;aIter != (*m_aInsertRow)->end();++aIter)
+        }
     }
 }
 
@@ -1579,7 +1556,6 @@ ORowSetMatrix::iterator	ORowSetCache::calcPosition() const
     return ( nValue < 0 || nValue >= static_cast<sal_Int32>(m_pMatrix->size()) ) ? m_pMatrix->end() : (m_pMatrix->begin() + nValue);
 }
 
-
 TORowSetOldRowHelperRef ORowSetCache::registerOldRow()
 {
     TORowSetOldRowHelperRef pRef = new ORowSetOldRowHelper(ORowSetRow());
@@ -1612,7 +1588,7 @@ sal_Bool ORowSetCache::reFillMatrix(sal_Int32 _nNewStartPos,sal_Int32 _nNewEndPo
     sal_Int32 nNewSt = _nNewStartPos;
     sal_Bool bRet = fillMatrix(nNewSt,_nNewEndPos);
     m_nStartPos = nNewSt - 1;
-    rotateCacheIterator(static_cast<sal_Int16>(m_nFetchSize+1)); // forces that every iterator will be set to null
+    rotateCacheIterator(static_cast<sal_Int16>(m_nFetchSize+1)); // forces every iterator to null
     return bRet;
 }
 
@@ -1666,7 +1642,7 @@ void ORowSetCache::impl_updateRowFromCache_throw(ORowSetValueVector::Vector& io_
                 break;
             }
         }
-        
+
         if ( aIter == m_pMatrix->end() )
         {
             m_pCacheSet->fillMissingValues(io_aRow);
