@@ -41,6 +41,7 @@
 #include <svtools/imgdef.hxx>
 #include "browserids.hxx"
 #include <connectivity/dbtools.hxx>
+#include <osl/diagnose.h>
 //......................................................................
 namespace dbaui
 {
@@ -145,14 +146,14 @@ namespace dbaui
     //------------------------------------------------------------------
     void DbaIndexList::enableSelectHandler()
     {
-        DBG_ASSERT(m_bSuspendSelectHdl, "DbaIndexList::enableSelectHandler: invalid call (this is not cumulative)!");
+        OSL_ENSURE(m_bSuspendSelectHdl, "DbaIndexList::enableSelectHandler: invalid call (this is not cumulative)!");
         m_bSuspendSelectHdl = sal_False;
     }
 
     //------------------------------------------------------------------
     void DbaIndexList::disableSelectHandler()
     {
-        DBG_ASSERT(!m_bSuspendSelectHdl, "DbaIndexList::enableSelectHandler: invalid call (this is not cumulative)!");
+        OSL_ENSURE(!m_bSuspendSelectHdl, "DbaIndexList::enableSelectHandler: invalid call (this is not cumulative)!");
         m_bSuspendSelectHdl = sal_True;
     }
 
@@ -186,7 +187,7 @@ DBG_NAME(DbaIndexDialog)
                                     const Reference< XMultiServiceFactory >& _rxORB,sal_Int32 _nMaxColumnsInIndex)
         :ModalDialog( _pParent, ModuleRes(DLG_INDEXDESIGN))
         ,m_xConnection(_rxConnection)
-        ,m_aGeometrySettings(E_DIALOG, ::rtl::OUString::createFromAscii("dbaccess.tabledesign.indexdialog"))
+        ,m_aGeometrySettings(E_DIALOG, ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("dbaccess.tabledesign.indexdialog")))
         ,m_aActions							(this, ModuleRes(TLB_ACTIONS))
         ,m_aIndexes							(this, ModuleRes(CTR_INDEXLIST))
         ,m_aIndexDetails					(this, ModuleRes(FL_INDEXDETAILS))
@@ -229,7 +230,7 @@ DBG_NAME(DbaIndexDialog)
         }
         catch(Exception&)
         {
-            OSL_ENSURE(sal_False, "DbaIndexDialog::DbaIndexDialog: could not retrieve basic information from the UNO collection!");
+            OSL_FAIL("DbaIndexDialog::DbaIndexDialog: could not retrieve basic information from the UNO collection!");
         }
 
         fillIndexList();
@@ -239,14 +240,6 @@ DBG_NAME(DbaIndexDialog)
 
         m_aClose.SetClickHdl(LINK(this, DbaIndexDialog, OnCloseDialog));
 
-        // get our most recent geometry settings
-//		if (m_aGeometrySettings.Exists())
-//		{
-//			Point aPos;
-//			m_aGeometrySettings.GetPosition(aPos.X(), aPos.Y());
-//			SetPosPixel(aPos);
-//		}
-
         // if all of the indexes have an empty description, we're not interested in displaying it
         Indexes::const_iterator aCheck;
 
@@ -316,8 +309,7 @@ DBG_NAME(DbaIndexDialog)
     //------------------------------------------------------------------
     void DbaIndexDialog::fillIndexList()
     {
-        sal_Bool bHiContrast = GetSettings().GetStyleSettings().GetHighContrastMode();
-        Image aPKeyIcon(ModuleRes( bHiContrast ? IMG_PKEYICON_SCH : IMG_PKEYICON));
+        Image aPKeyIcon(ModuleRes( IMG_PKEYICON ));
         // fill the list with the index names
         m_aIndexes.Clear();
         Indexes::iterator aIndexLoop = m_pIndexes->begin();
@@ -343,17 +335,13 @@ DBG_NAME(DbaIndexDialog)
         delete m_pIndexes;
         delete m_pFields;
 
-        // save our geometry settings
-//		Point aPos = GetPosPixel();
-//		m_aGeometrySettings.SetPosition(aPos.X(), aPos.Y());
-    
         DBG_DTOR(DbaIndexDialog,NULL);
     }
 
     //------------------------------------------------------------------
     sal_Bool DbaIndexDialog::implCommit(SvLBoxEntry* _pEntry)
     {
-        DBG_ASSERT(_pEntry, "DbaIndexDialog::implCommit: invalid entry!");
+        OSL_ENSURE(_pEntry, "DbaIndexDialog::implCommit: invalid entry!");
 
         Indexes::iterator aCommitPos = m_pIndexes->begin() + reinterpret_cast<sal_IntPtr>(_pEntry->GetUserData());
 
@@ -408,7 +396,7 @@ DBG_NAME(DbaIndexDialog)
         }
         if ((i>0x7FFFFFFF) || (i<0))
         {
-            DBG_ERROR("DbaIndexDialog::OnNewIndex: no free index name found!");
+            OSL_FAIL("DbaIndexDialog::OnNewIndex: no free index name found!");
             // can't do anything ... of course we try another base, but this could end with the same result ...
             return;
         }
@@ -421,7 +409,7 @@ DBG_NAME(DbaIndexDialog)
         for (SvLBoxEntry* pAdjust = m_aIndexes.First(); pAdjust; pAdjust = m_aIndexes.Next(pAdjust))
         {
             Indexes::iterator aAfterInsertPos = m_pIndexes->find(m_aIndexes.GetEntryText(pAdjust));
-            DBG_ASSERT(aAfterInsertPos != m_pIndexes->end(), "DbaIndexDialog::OnNewIndex: problems with on of the entries!");
+            OSL_ENSURE(aAfterInsertPos != m_pIndexes->end(), "DbaIndexDialog::OnNewIndex: problems with on of the entries!");
             pAdjust->SetUserData(reinterpret_cast< void* >(sal_Int32(aAfterInsertPos - m_pIndexes->begin())));
         }
 
@@ -437,7 +425,7 @@ DBG_NAME(DbaIndexDialog)
     {
         // the selected index
         SvLBoxEntry* pSelected = m_aIndexes.FirstSelected();
-        DBG_ASSERT(pSelected, "DbaIndexDialog::OnDropIndex: invalid call!");
+        OSL_ENSURE(pSelected, "DbaIndexDialog::OnDropIndex: invalid call!");
         if (pSelected)
         {
             // let the user confirm the drop
@@ -463,7 +451,7 @@ DBG_NAME(DbaIndexDialog)
     {
         // do the drop
         Indexes::iterator aDropPos = m_pIndexes->begin() + reinterpret_cast<sal_IntPtr>(_pEntry->GetUserData());
-        DBG_ASSERT(aDropPos != m_pIndexes->end(), "DbaIndexDialog::OnDropIndex: did not find the index in my collection!");
+        OSL_ENSURE(aDropPos != m_pIndexes->end(), "DbaIndexDialog::OnDropIndex: did not find the index in my collection!");
 
         SQLExceptionInfo aExceptionInfo;
         sal_Bool bSuccess = sal_False;
@@ -493,7 +481,7 @@ DBG_NAME(DbaIndexDialog)
             for (SvLBoxEntry* pAdjust = m_aIndexes.First(); pAdjust; pAdjust = m_aIndexes.Next(pAdjust))
             {
                 Indexes::iterator aAfterDropPos = m_pIndexes->find(m_aIndexes.GetEntryText(pAdjust));
-                DBG_ASSERT(aAfterDropPos != m_pIndexes->end(), "DbaIndexDialog::OnDropIndex: problems with on of the remaining entries!");
+                OSL_ENSURE(aAfterDropPos != m_pIndexes->end(), "DbaIndexDialog::OnDropIndex: problems with on of the remaining entries!");
                 pAdjust->SetUserData(reinterpret_cast< void* >(sal_Int32(aAfterDropPos - m_pIndexes->begin())));
             }
 
@@ -514,7 +502,7 @@ DBG_NAME(DbaIndexDialog)
     {
         // the selected index
         SvLBoxEntry* pSelected = m_aIndexes.FirstSelected();
-        DBG_ASSERT(pSelected, "DbaIndexDialog::OnRenameIndex: invalid call!");
+        OSL_ENSURE(pSelected, "DbaIndexDialog::OnRenameIndex: invalid call!");
 
         // save the changes made 'til here
         // Upon leaving the edit mode, the control will be re-initialized with the
@@ -543,7 +531,7 @@ DBG_NAME(DbaIndexDialog)
     {
         // the selected index
         SvLBoxEntry* pSelected = m_aIndexes.FirstSelected();
-        DBG_ASSERT(pSelected, "DbaIndexDialog::OnResetIndex: invalid call!");
+        OSL_ENSURE(pSelected, "DbaIndexDialog::OnResetIndex: invalid call!");
 
         Indexes::iterator aResetPos = m_pIndexes->begin() + reinterpret_cast<sal_IntPtr>(pSelected->GetUserData());
 
@@ -601,7 +589,7 @@ DBG_NAME(DbaIndexDialog)
     {
         if (m_aIndexes.IsEditingActive())
         {
-            DBG_ASSERT(!m_bEditAgain, "DbaIndexDialog::OnCloseDialog: somebody was faster than hell!");
+            OSL_ENSURE(!m_bEditAgain, "DbaIndexDialog::OnCloseDialog: somebody was faster than hell!");
                 // this means somebody entered a new name, which was invalid, which cause us to posted us an event,
                 // and before the event arrived the user clicked onto "close". VERY fast, this user ....
             m_aIndexes.EndEditing(sal_False);
@@ -612,7 +600,7 @@ DBG_NAME(DbaIndexDialog)
 
         // the currently selected entry
         const SvLBoxEntry* pSelected = m_aIndexes.FirstSelected();
-        DBG_ASSERT(pSelected == m_pPreviousSelection, "DbaIndexDialog::OnCloseDialog: inconsistence!");
+        OSL_ENSURE(pSelected == m_pPreviousSelection, "DbaIndexDialog::OnCloseDialog: inconsistence!");
 
         sal_Int32 nResponse = RET_NO;
         if (pSelected)
@@ -657,7 +645,7 @@ DBG_NAME(DbaIndexDialog)
     {
         Indexes::iterator aPosition = m_pIndexes->begin() + reinterpret_cast<sal_IntPtr>(_pEntry->GetUserData());
         
-        DBG_ASSERT(aPosition >= m_pIndexes->begin() && aPosition < m_pIndexes->end(),
+        OSL_ENSURE(aPosition >= m_pIndexes->begin() && aPosition < m_pIndexes->end(),
             "DbaIndexDialog::OnEntryEdited: invalid entry!");
 
         String sNewName = m_aIndexes.GetEntryText(_pEntry);
@@ -781,7 +769,7 @@ DBG_NAME(DbaIndexDialog)
     //------------------------------------------------------------------
     IMPL_LINK( DbaIndexDialog, OnModified, void*, /*NOTINTERESTEDIN*/ )
     {
-        DBG_ASSERT(m_pPreviousSelection, "DbaIndexDialog, OnModified: invalid call!");
+        OSL_ENSURE(m_pPreviousSelection, "DbaIndexDialog, OnModified: invalid call!");
         Indexes::iterator aPosition = m_pIndexes->begin() + reinterpret_cast<sal_IntPtr>(m_pPreviousSelection->GetUserData());
 
         aPosition->setModified(sal_True);
@@ -889,22 +877,19 @@ DBG_NAME(DbaIndexDialog)
         }
     }
     //------------------------------------------------------------------
-    ImageList DbaIndexDialog::getImageList(sal_Int16 _eBitmapSet,sal_Bool _bHiContast) const
+    ImageList DbaIndexDialog::getImageList(sal_Int16 _eBitmapSet) const
     {
         sal_Int16 nN = IMG_INDEX_DLG_SC;
-        sal_Int16 nH = IMG_INDEX_DLG_SCH;
         if ( _eBitmapSet == SFX_SYMBOLS_SIZE_LARGE )	 	 
         {
             nN = IMG_INDEX_DLG_LC;
-            nH = IMG_INDEX_DLG_LCH;
-        } // if ( _eBitmapSet == SFX_SYMBOLS_LARGE )
-        return ImageList(ModuleRes( _bHiContast ? nH : nN ));
+        }
+        return ImageList( nN );
     }
     //------------------------------------------------------------------
     void DbaIndexDialog::resizeControls(const Size& _rDiff)
     {
         // we use large images so we must change them
-        Size aTbNewSize = m_aActions.GetSizePixel();
         if ( _rDiff.Width() || _rDiff.Height() )
         {
             Size aDlgSize = GetSizePixel();
