@@ -110,7 +110,7 @@ OSectionWindow::OSectionWindow( OViewsWindow* _pParent,const uno::Reference< rep
     }
     
     _propertyChanged(aEvent);
-    SetPaintTransparent(TRUE);
+    SetPaintTransparent(sal_True);
 }
 // -----------------------------------------------------------------------------
 OSectionWindow::~OSectionWindow()
@@ -136,18 +136,15 @@ void OSectionWindow::_propertyChanged(const beans::PropertyChangeEvent& _rEvent)
         const uno::Reference< report::XSection> xCurrentSection = m_aReportSection.getSection();
         if ( _rEvent.PropertyName.equals(PROPERTY_HEIGHT) )
         {
-            m_pParent->getView()->SetUpdateMode(FALSE);
+            m_pParent->getView()->SetUpdateMode(sal_False);
             Resize();
             m_pParent->getView()->notifySizeChanged();
             m_pParent->resize(*this);
-            m_pParent->getView()->SetUpdateMode(TRUE);
+            m_pParent->getView()->SetUpdateMode(sal_True);
             m_aStartMarker.Invalidate(INVALIDATE_NOERASE);
             m_aEndMarker.Invalidate(INVALIDATE_NOERASE);
             m_aReportSection.Invalidate(/*INVALIDATE_NOERASE*/);
             getViewsWindow()->getView()->getReportView()->getController().resetZoomType();
-            // Invalidate(INVALIDATE_NOCHILDREN | INVALIDATE_TRANSPARENT);
-            // m_pParent->Invalidate(INVALIDATE_NOCHILDREN|INVALIDATE_NOERASE|INVALIDATE_TRANSPARENT);
-            // m_pParent->Invalidate(/*INVALIDATE_NOCHILDREN | INVALIDATE_NOERASE |*/ INVALIDATE_NOCHILDREN | INVALIDATE_TRANSPARENT);
         }
         else if ( _rEvent.PropertyName.equals(PROPERTY_NAME) && !xSection->getGroup().is() )
         {
@@ -164,7 +161,7 @@ void OSectionWindow::_propertyChanged(const beans::PropertyChangeEvent& _rEvent)
                 m_aStartMarker.Invalidate(INVALIDATE_CHILDREN);
             }
         }
-    } // if ( xSection.is() )
+    }
     else if ( _rEvent.PropertyName.equals(PROPERTY_EXPRESSION) )
     {
         uno::Reference< report::XGroup > xGroup(_rEvent.Source,uno::UNO_QUERY);
@@ -176,7 +173,7 @@ void OSectionWindow::_propertyChanged(const beans::PropertyChangeEvent& _rEvent)
     }
 }
 // -----------------------------------------------------------------------------
-bool OSectionWindow::setReportSectionTitle(const uno::Reference< report::XReportDefinition>& _xReport,USHORT _nResId,::std::mem_fun_t<uno::Reference<report::XSection> , OReportHelper> _pGetSection,::std::mem_fun_t<sal_Bool,OReportHelper> _pIsSectionOn)
+bool OSectionWindow::setReportSectionTitle(const uno::Reference< report::XReportDefinition>& _xReport,sal_uInt16 _nResId,::std::mem_fun_t<uno::Reference<report::XSection> , OReportHelper> _pGetSection,::std::mem_fun_t<sal_Bool,OReportHelper> _pIsSectionOn)
 {
     OReportHelper aReportHelper(_xReport);
     const bool bRet = _pIsSectionOn(&aReportHelper) && _pGetSection(&aReportHelper) == m_aReportSection.getSection();
@@ -185,11 +182,11 @@ bool OSectionWindow::setReportSectionTitle(const uno::Reference< report::XReport
         String sTitle = String(ModuleRes(_nResId));
         m_aStartMarker.setTitle(sTitle);
         m_aStartMarker.Invalidate(INVALIDATE_CHILDREN);
-    } // if ( bRet )
+    }
     return bRet;
 }
 // -----------------------------------------------------------------------------
-bool OSectionWindow::setGroupSectionTitle(const uno::Reference< report::XGroup>& _xGroup,USHORT _nResId,::std::mem_fun_t<uno::Reference<report::XSection> , OGroupHelper> _pGetSection,::std::mem_fun_t<sal_Bool,OGroupHelper> _pIsSectionOn)
+bool OSectionWindow::setGroupSectionTitle(const uno::Reference< report::XGroup>& _xGroup,sal_uInt16 _nResId,::std::mem_fun_t<uno::Reference<report::XSection> , OGroupHelper> _pGetSection,::std::mem_fun_t<sal_Bool,OGroupHelper> _pIsSectionOn)
 {
     OGroupHelper aGroupHelper(_xGroup);
     const bool bRet = _pIsSectionOn(&aGroupHelper) && _pGetSection(&aGroupHelper) == m_aReportSection.getSection() ;
@@ -206,14 +203,13 @@ bool OSectionWindow::setGroupSectionTitle(const uno::Reference< report::XGroup>&
         sTitle.SearchAndReplace('#',sExpression);
         m_aStartMarker.setTitle(sTitle);
         m_aStartMarker.Invalidate(INVALIDATE_CHILDREN);
-    } // if ( _pIsSectionOn(&aGroupHelper) )
+    }
     return bRet;
 }
 //------------------------------------------------------------------------------
 void OSectionWindow::ImplInitSettings()
 {
     SetBackground( );
-    //SetBackground( Wallpaper( COL_RED ));
 }
 //-----------------------------------------------------------------------------
 void OSectionWindow::DataChanged( const DataChangedEvent& rDCEvt )
@@ -309,8 +305,6 @@ IMPL_LINK( OSectionWindow, Collapsed, OColorListener *, _pMarker )
 
         m_pParent->resize(*this);
         Resize();
-        // TRY
-        // m_pParent->Invalidate(INVALIDATE_TRANSPARENT | INVALIDATE_NOCHILDREN);
         Invalidate();
     }
     return 0L;
@@ -324,21 +318,19 @@ void OSectionWindow::zoom(const Fraction& _aZoom)
     setZoomFactor(_aZoom,m_aReportSection);
     setZoomFactor(_aZoom,m_aSplitter);
     setZoomFactor(_aZoom,m_aEndMarker);
-    //Resize();
-    Invalidate(/*INVALIDATE_UPDATE |*/ /* | INVALIDATE_TRANSPARENT *//*INVALIDATE_NOCHILDREN*/);
+    Invalidate();
 }
 //-----------------------------------------------------------------------------
 IMPL_LINK( OSectionWindow, StartSplitHdl, Splitter*,  )
 {
-    const String sEmpty(ModuleRes(RID_STR_UNDO_CHANGE_SIZE));
-    getViewsWindow()->getView()->getReportView()->getController().getUndoMgr()->EnterListAction(sEmpty,String()); 
+    const String sUndoAction( ModuleRes( RID_STR_UNDO_CHANGE_SIZE ) );
+    getViewsWindow()->getView()->getReportView()->getController().getUndoManager().EnterListAction( sUndoAction, String() ); 
     return 0L;
 }
 //------------------------------------------------------------------------------
 IMPL_LINK( OSectionWindow, EndSplitHdl, Splitter*,  )
 {
-    getViewsWindow()->getView()->getReportView()->getController().getUndoMgr()->LeaveListAction(); 
-    /*getViewsWindow()->Resize();*/
+    getViewsWindow()->getView()->getReportView()->getController().getUndoManager().LeaveListAction(); 
     return 0L;
 }
 //-----------------------------------------------------------------------------
@@ -350,22 +342,19 @@ IMPL_LINK( OSectionWindow, SplitHdl, Splitter*, _pSplitter )
     }
 
     sal_Int32 nSplitPos = _pSplitter->GetSplitPosPixel();
-    const Point aPos = _pSplitter->GetPosPixel();
-    
 
     const uno::Reference< report::XSection> xSection = m_aReportSection.getSection();
     nSplitPos = m_aSplitter.PixelToLogic(Size(0,nSplitPos)).Height();
-    // nSplitPos = xSection->getHeight() + m_aSplitter.PixelToLogic(Size(0,nSplitPos - aPos.Y() )).Height();
     
     const sal_Int32 nCount = xSection->getCount();
     for (sal_Int32 i = 0; i < nCount; ++i)
     {
         uno::Reference<report::XReportComponent> xReportComponent(xSection->getByIndex(i),uno::UNO_QUERY);
-        if ( xReportComponent.is() /*&& nSplitPos < (xReportComponent->getPositionY() + xReportComponent->getHeight())*/ )
+        if ( xReportComponent.is() )
         {
             nSplitPos = ::std::max(nSplitPos,xReportComponent->getPositionY() + xReportComponent->getHeight());
         }
-    } // for (sal_Int32 i = 0; i < nCount; ++i)
+    }
 
     if ( nSplitPos < 0 )
         nSplitPos = 0;
@@ -378,7 +367,7 @@ IMPL_LINK( OSectionWindow, SplitHdl, Splitter*, _pSplitter )
 // -----------------------------------------------------------------------------
 void lcl_scroll(Window& _rWindow,const Point& _aDelta)
 {
-    _rWindow.Scroll(-_aDelta.X(),-_aDelta.Y()/*,SCROLL_CHILDREN*//*|SCROLL_CLIP*/);
+    _rWindow.Scroll(-_aDelta.X(),-_aDelta.Y());
     _rWindow.Invalidate(INVALIDATE_TRANSPARENT);
 }
 // -----------------------------------------------------------------------------
@@ -401,11 +390,9 @@ void OSectionWindow::scrollChildren(long _nX)
     const Point aNew = aMapMode.GetOrigin();
     const Point aDiff = aOld - aNew;
     {
-        //OWindowPositionCorrector aCorrector(&m_aReportSection,-aDelta.Width(),0);
         lcl_scroll(m_aReportSection,aDiff);
     }
     
-    //lcl_setOrigin(m_aEndMarker,_nDeltaX, 0);
     lcl_scroll(m_aEndMarker,m_aEndMarker.PixelToLogic(Point(_nX,0)));
     
     lcl_setOrigin(m_aSplitter,_nX, 0);
